"use strict";

const ee = require("./eventemitter");

/**
 * Throttle the window.resize event for better performance
 * See: https://developer.mozilla.org/en-US/docs/Web/Events/resize
 */
const throttle = function(obj, type, name, callback) {
  obj = obj || window;
  let running = false;
  const func = function(eventDetail) {
    if (running) {
      return;
    }
    running = true;
    window.requestAnimationFrame(function onAnimationFrame() {
      let params = [eventDetail];
      let result = null;
      if (callback) {
        result = (typeof callback === "function") ? callback() : callback;
      }
      params = params.concat(Array.isArray(result) ? result : [result]);
      ee.trigger(name, params);
      running = false;
    });
  };
  obj.addEventListener(type, func);
};

module.exports = throttle;
